@@ -233,6 +233,12 @@ async def debug_mcp_docker(image: str) -> None:
 
     logger.info(f"\n{Colors.BOLD}🔍 Docker MCP Server Debugger{Colors.ENDC}")
     logger.info(f"{Colors.GRAY}Image: {image}{Colors.ENDC}")
+
+    # Show extra docker args if provided
+    extra_args = getattr(__builtins__, "_docker_extra_args", [])
+    if extra_args:
+        logger.info(f"{Colors.GRAY}Extra args: {' '.join(extra_args)}{Colors.ENDC}")
+
     logger.info(f"{Colors.GRAY}Time: {datetime.now().strftime('%Y-%m-%d %H:%M:%S')}{Colors.ENDC}")
 
     # Explain color coding
@@ -253,7 +259,9 @@ async def debug_mcp_docker(image: str) -> None:
     log_phase(1, "Basic Docker Container Test")
 
     try:
-        cmd = ["docker", "run", "--rm", image, "echo", "Container OK"]
+        # Get extra docker args if provided
+        extra_args = getattr(__builtins__, "_docker_extra_args", [])
+        cmd = ["docker", "run", "--rm"] + extra_args + [image, "echo", "Container OK"]
         log_command(cmd)
 
         result = subprocess.run(cmd, capture_output=True, text=True, timeout=10)
@@ -293,7 +301,9 @@ async def debug_mcp_docker(image: str) -> None:
     }
 
     try:
-        cmd = ["docker", "run", "--rm", "-i", image]
+        # Get extra docker args if provided
+        extra_args = getattr(__builtins__, "_docker_extra_args", [])
+        cmd = ["docker", "run", "--rm", "-i"] + extra_args + [image]
         log_command(cmd)
 
         log_stdio(f"Sending: {json.dumps(init_request)}")
@@ -395,7 +405,11 @@ async def debug_mcp_docker(image: str) -> None:
     try:
         from hud.mcp import MCPClient
 
-        mcp_config = {"test": {"command": "docker", "args": ["run", "--rm", "-i", image]}}
+        # Get extra docker args if provided
+        extra_args = getattr(__builtins__, "_docker_extra_args", [])
+        mcp_config = {
+            "test": {"command": "docker", "args": ["run", "--rm", "-i"] + extra_args + [image]}
+        }
 
         cmd = ["docker"] + mcp_config["test"]["args"]
         log_command(cmd)
@@ -618,12 +632,18 @@ async def debug_mcp_docker(image: str) -> None:
 
         log_info(f"Baseline: Memory={baseline_memory:.1f}MB, CPU={baseline_cpu:.1f}%")
 
+        # Get extra docker args if provided
+        extra_args = getattr(__builtins__, "_docker_extra_args", [])
+
         # Create multiple concurrent clients
         log_info("Creating 3 concurrent MCP clients...")
 
         for i in range(3):
             client_config = {
-                f"test_concurrent_{i}": {"command": "docker", "args": ["run", "--rm", "-i", image]}
+                f"test_concurrent_{i}": {
+                    "command": "docker",
+                    "args": ["run", "--rm", "-i"] + extra_args + [image],
+                }
             }
 
             concurrent_client = MCPClient(mcp_config=client_config, verbose=False)
@@ -689,11 +709,14 @@ async def debug_mcp_docker(image: str) -> None:
 
         # Still test basic concurrent connections
         try:
+            # Get extra docker args if provided
+            extra_args = getattr(__builtins__, "_docker_extra_args", [])
+
             for i in range(3):
                 client_config = {
                     f"test_concurrent_{i}": {
                         "command": "docker",
-                        "args": ["run", "--rm", "-i", image],
+                        "args": ["run", "--rm", "-i"] + extra_args + [image],
                     }
                 }
 
@@ -734,10 +757,29 @@ async def debug_mcp_docker(image: str) -> None:
 
 
 if __name__ == "__main__":
-    if len(sys.argv) != 2:
-        print("Usage: python docker_debug.py <docker-image>")
+    import warnings
+    import gc
+
+    if len(sys.argv) < 2:
+        print("Usage: python docker_debug.py <docker-image> [docker-args...]")
         print("Example: python docker_debug.py hudpython/gmail-clone:latest")
+        print(
+            "Example: python docker_debug.py my-env:latest -e BROWSER_PROVIDER=browserbase -e API_KEY=xxx"
+        )
         sys.exit(1)
 
     docker_image = sys.argv[1]
+    docker_extra_args = sys.argv[2:] if len(sys.argv) > 2 else []
+
+    # Suppress cleanup warnings
+    warnings.filterwarnings("ignore", category=ResourceWarning)
+
+    # Store extra args globally so they can be used in docker commands
+    import builtins
+
+    setattr(builtins, "_docker_extra_args", docker_extra_args)
+
     asyncio.run(debug_mcp_docker(docker_image))
+
+    # Force cleanup to avoid warnings
+    gc.collect()
